#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-01-06
#
#
# missing a way to include hostname and service description
#

from cmk.gui.i18n import _

from cmk.gui.plugins.metrics import (
    metric_info,
    graph_info,
    perfometer_info

)

#####################################################################################################################
#
# define metrics for perfdata
#
#####################################################################################################################

metric_info['cisco_wlc_uptime_seconds'] = {
    'title': _('AP uptime'),
    'help': _(''),
    'unit': 's',
    'color': '26/a',
}

metric_info['cisco_wlc_lwap_uptime_seconds'] = {
    'title': _('LWAP uptime'),
    'help': _(''),
    'unit': 's',
    'color': '41/a',
}

metric_info['cisco_wlc_active_client_count'] = {
    'title': _('Active clients'),
    'help': _(''),
    'unit': 'count',
    'color': '11/a',
}

metric_info['cisco_wlc_associated_clients'] = {
    'title': _('Associated clients'),
    'help': _(''),
    'unit': 'count',
    'color': '23/a',
}

metric_info['cisco_wlc_reassoiation_success_count'] = {
    'title': _('Reassoiation success'),
    'help': _(''),
    'unit': '1/s',
    'color': '21/a',
}

metric_info['cisco_wlc_reassoiation_failure_count'] = {
    'title': _('Reassoiation failure'),
    'help': _(''),
    'unit': '1/s',
    'color': '31/a',
}

metric_info['cisco_wlc_reassoiation_failure_count_by_rate'] = {
    'title': _('Reassoiation failure rate'),
    'help': _(''),
    'unit': '1/s',
    'color': '41/a',
}

metric_info['cisco_wlc_echo_request_count'] = {
    'title': _('Echo request'),
    'help': _(''),
    'unit': '1/s',
    'color': '12/a',
}

metric_info['cisco_wlc_echo_response_loss_count'] = {
    'title': _('Echo response loss'),
    'help': _(''),
    'unit': '1/s',
    'color': '22/a',
}

metric_info['cisco_wlc_association_fail_count_for_rssi_low'] = {
    'title': _('Association fail rssi low'),
    'help': _(''),
    'unit': '1/s',
    'color': '32/a',
}

metric_info['cisco_wlc_association_fail_times'] = {
    'title': _('Association fail times'),
    'help': _(''),
    'unit': '1/s',
    'color': '42/a',
}

metric_info['cisco_wlc_association_count'] = {
    'title': _('Associations'),
    'help': _(''),
    'unit': '1/s',
    'color': '13/a',
}

######################################################################################################################
#
# how to graph perdata
#
######################################################################################################################

graph_info['cisco_wlc.ap_uptime'] = {
    'title': _('AP/LWAP Uptime'),
    'metrics': [
        ('cisco_wlc_lwap_uptime_seconds', '-area'),
        ('cisco_wlc_uptime_seconds', 'area'),
    ],
    'optional_metrics': ['cisco_wlc_lwap_uptime_seconds'],
}

graph_info['cisco_wlc.active_client'] = {
    'title': _('Active clients'),
    'metrics': [
        ('cisco_wlc_active_client_count', 'area'),
        ('cisco_wlc_associated_clients', 'line'),
    ],
}

graph_info['cisco_wlc.counters'] = {
    'title': _('Counters'),
    'metrics': [
        ('cisco_wlc_reassoiation_success_count', 'line'),
        ('cisco_wlc_reassoiation_failure_count', 'line'),
        ('cisco_wlc_association_fail_times', 'line'),
        ('cisco_wlc_association_fail_count_for_rssi_low', 'line'),
        ('cisco_wlc_association_count', 'line'),
    ],
}

graph_info['cisco_elc_echo'] = {
    'title': _('Echos'),
    'metrics': [
        ('cisco_wlc_echo_request_count', 'area'),
        ('cisco_wlc_echo_response_loss_count', '-area'),
    ],
}

######################################################################################################################
#
# define perf-o-meter
#
######################################################################################################################

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'cisco_wlc_uptime_seconds',
        'half_value': 2592000.0,
        'exponent': 2,
    },
    {
        'type': 'linear',
        'segments': ['cisco_wlc_active_client_count'],
        'total': 200,
    }
]))
